searchData={"items":[{"type":"task","title":"mix phx.react.bun.bundle","doc":"Create server.js bundle for `bun` runtime,\nbundle all components and render server in one file for otp release.","ref":"Mix.Tasks.Phx.React.Bun.Bundle.html"},{"type":"task","title":"Usage - mix phx.react.bun.bundle","doc":"```shell\nmix phx.react.bun.bundle --component-base=assets/component --output=priv/react/server.js\n```","ref":"Mix.Tasks.Phx.React.Bun.Bundle.html#module-usage"},{"type":"function","title":"Mix.Tasks.Phx.React.Bun.Bundle.find_files/1","doc":"","ref":"Mix.Tasks.Phx.React.Bun.Bundle.html#find_files/1"},{"type":"function","title":"Mix.Tasks.Phx.React.Bun.Bundle.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.Phx.React.Bun.Bundle.html#run/1"},{"type":"module","title":"Phoenix.React","doc":"Run a `react` render server to render react component in `Phoenix` html.\n\n**Features**\n\n- [x] Render to static markup\n- [x] Render to string\n- [x] Render to readable stream\n- [x] Hydrate at client side\n- [x] Connect to Live View render\n\nSee the [docs](https://hexdocs.pm/phoenix_react_server/) for more information.","ref":"Phoenix.React.html"},{"type":"module","title":"Install this package - Phoenix.React","doc":"Add deps in `mix.exs`\n\n```elixir\n{:phoenix_react_server, \"~> 0.5\"},\n```","ref":"Phoenix.React.html#module-install-this-package"},{"type":"module","title":"Configuration - Phoenix.React","doc":"Set config, runtime, react components, etc.\n\n```elixir\nimport Config\n\nconfig :phoenix_react_server, Phoenix.React,\n  # react runtime, default to `bun`\n  runtime: Phoenix.React.Runtime.Bun,\n  # react component base path\n  component_base: Path.expand(\"../assets/component\", __DIR__),\n  # cache ttl, default to 60 seconds\n  cache_ttl: 60\n```\n\nSupported `runtime`\n\n- [x] `Phoenix.React.Runtime.Bun`\n- [ ] `Phoenix.React.Runtime.Deno`\n\nAdd Render Server in your application Supervisor tree.\n\n```elixir\n  def start(_type, _args) do\n    children = [\n      ReactDemoWeb.Telemetry,\n      {DNSCluster, query: Application.get_env(:react_demo, :dns_cluster_query) || :ignore},\n      {Phoenix.PubSub, name: ReactDemo.PubSub},\n      # React render service\n      Phoenix.React,\n      ReactDemoWeb.Endpoint\n    ]\n\n    opts = [strategy: :one_for_one, name: ReactDemo.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n```\n\nWrite Phoenix Component use `react_component`\n\n```elixir\ndefmodule ReactDemoWeb.ReactComponents do\n  use Phoenix.Component\n\n  import Phoenix.React.Helper\n\n  def react_markdown(assigns) do\n    {static, props} = Map.pop(assigns, :static, true)\n\n    react_component(%{\n      component: \"markdown\",\n      props: props,\n      static: static\n    })\n  end\nend\n```\n\nImport in html helpers in `react_demo_web.ex`\n\n```elixir\n  defp html_helpers do\n    quote do\n      # Translation\n      use Gettext, backend: ReactDemoWeb.Gettext\n\n      # HTML escaping functionality\n      import Phoenix.HTML\n      # Core UI components\n      import ReactDemoWeb.CoreComponents\n      import ReactDemoWeb.ReactComponents\n\n      ...\n    end\n  end\n```\n\n### `render_to_static_markup`\n\nThen you can use react server rendered component in Phoenix Component\n\n```html\n \n   \n     Hello There \n    <.react_markdown\n      data={@data}\n    >\n   \n \n```\n\n### `render_to_string`\n\n```html\n \n   \n     \n      This  Table  is rendered with  react-dom/server \n     \n    <!-- Notice: Remove white space in the react render node or it will break hydrate -->\n     <.react_system_stats\n      data={@data}\n    /> \n   \n \n```\n\n* Then hydrate on the client.\n\n```js\n\ndocument.addEventListener('DOMContentLoaded', function() {\n  const store = new Store();\n  const domContainer = document.querySelector('#system_usage_container');\n  if (domContainer) {\n    let channel = socket.channel(\"system_usage:lobby\", {});\n\n    channel.join()\n      .receive(\"ok\", resp => { console.log(\"Joined successfully\", resp) })\n      .receive(\"error\", resp => { console.log(\"Unable to join\", resp) });\n\n\n    function Usage(props) {\n      const data = useSyncExternalStore(store.subscribe, store.getSnapshot, store.getServerSnapshot);\n\n      return  ;\n    }\n\n    let root;\n\n    channel.on(\"joined\", (data) => {\n      // console.log(\"Reset stats: \", data)\n      store.reset(data.data)\n\n      requestAnimationFrame(() => {\n        hydrateRoot(domContainer,  );\n      });\n    });\n\n    channel.on(\"stats\", (data) => {\n      // console.log(\"Stats: \", data)\n      store.unshift(data)\n    });\n\n  }\n});\n\n```\n\n### `render_to_readable_stream`\n\n```html\n <.react_live_form\n  data={@form_data}\n/> \n```\n\n* Work with `LiveView`\n\n```js\n\nconst hooks = {\n  LiveFormHook: {\n    mounted() {\n      const formState = new FormState();\n\n      formState.setData = (data) => {\n        this.pushEvent(\"form:input\", data);\n      };\n\n      function LiveViewForm(props) {\n        const data = useSyncExternalStore(formState.subscribe, formState.getSnapshot, formState.getServerSnapshot);\n        return  ;\n      }\n\n      this.pushEvent(\"form:init\", {}, (data, ref) => {\n        formState.reset(data);\n        this.reactRoot = hydrateRoot(this.el,  );\n      });\n      this.handleEvent(\"form:update\", (data) => {\n        formState.assign(data);\n      });\n    },\n  }\n}\n```","ref":"Phoenix.React.html#module-configuration"},{"type":"module","title":"Run in release mode - Phoenix.React","doc":"Bundle components with server.js to one file.\n\n```shell\nmix phx.react.bun.bundle --component-base=assets/component --output=priv/react/server.js\n```\n\nConfig `runtime` to `Phoenix.React.Runtime.Bun` in `runtime.exs`\n\n```elixir\n\nconfig :phoenix_react_server, Phoenix.React.Runtime.Bun,\n  cmd: System.find_executable(\"bun\"),\n  server_js: Path.expand(\"../priv/react/server.js\", __DIR__),\n  port: 12666,\n  env: :prod\n```","ref":"Phoenix.React.html#module-run-in-release-mode"},{"type":"module","title":"Hydrate at client side with CDN - Phoenix.React","doc":"Hydrate react component at client side when CDN.\n\n```html\n \n  {\n    \"imports\": {\n      \"react-dom\": \"https://esm.run/react-dom@19\",\n      \"app\": \"https://my.web.site/app.js\"\n    }\n  }\n \n \nimport { hydrateRoot } from 'react-dom/client';\nimport { Component } from 'app';\n\nhydrateRoot(\n  document.getElementById('app-wrapper'),\n   \n);\n \n```","ref":"Phoenix.React.html#module-hydrate-at-client-side-with-cdn"},{"type":"function","title":"Phoenix.React.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Phoenix.React.html#child_spec/1"},{"type":"type","title":"Phoenix.React.component/0","doc":"React component file name\nMust export a `Component` function","ref":"Phoenix.React.html#t:component/0"},{"type":"function","title":"Phoenix.React.find_server_pid/0","doc":"","ref":"Phoenix.React.html#find_server_pid/0"},{"type":"type","title":"Phoenix.React.props/0","doc":"React component props\nMust be a json serializable map","ref":"Phoenix.React.html#t:props/0"},{"type":"function","title":"Phoenix.React.render_to_readable_stream/2","doc":"Render a React component to a string by call `renderToReadableStream` in `react-dom/server`","ref":"Phoenix.React.html#render_to_readable_stream/2"},{"type":"function","title":"Phoenix.React.render_to_static_markup/2","doc":"Render a React component to a string by call `renderToStaticMarkup` in `react-dom/server`","ref":"Phoenix.React.html#render_to_static_markup/2"},{"type":"function","title":"Phoenix.React.render_to_string/2","doc":"Render a React component to a string by call `renderToString` in `react-dom/server`","ref":"Phoenix.React.html#render_to_string/2"},{"type":"function","title":"Phoenix.React.start_link/1","doc":"","ref":"Phoenix.React.html#start_link/1"},{"type":"function","title":"Phoenix.React.stop_runtime/0","doc":"","ref":"Phoenix.React.html#stop_runtime/0"},{"type":"module","title":"Phoenix.React.Cache","doc":"Cache for React Component rendering\n\nCache key is a tuple of component, props and static flag\n\nRemove expired cache every 60 seconds","ref":"Phoenix.React.Cache.html"},{"type":"function","title":"Phoenix.React.Cache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Phoenix.React.Cache.html#child_spec/1"},{"type":"function","title":"Phoenix.React.Cache.delete_cache/3","doc":"Remove cached value","ref":"Phoenix.React.Cache.html#delete_cache/3"},{"type":"function","title":"Phoenix.React.Cache.get/3","doc":"Get a cached value","ref":"Phoenix.React.Cache.html#get/3"},{"type":"function","title":"Phoenix.React.Cache.put/5","doc":"Set a cached value","ref":"Phoenix.React.Cache.html#put/5"},{"type":"function","title":"Phoenix.React.Cache.start_link/1","doc":"","ref":"Phoenix.React.Cache.html#start_link/1"},{"type":"module","title":"Phoenix.React.Helper","doc":"A helper to render react component by `react-dom/server` in `Phoenix.Component`.\n\nUsage:\n\n```elixir\n# in html_helpers in AppWeb.ex\nimport Phoenix.React.Helper\n```","ref":"Phoenix.React.Helper.html"},{"type":"function","title":"Phoenix.React.Helper.react_component/1","doc":"A helper to render react component by `react-dom/server` in `Phoenix.Template`.\n\nattrs:\n  - `component`: react component name\n  - `props`: props will pass to react component\n  - `static`: when true, render to static markup, false to render to string for client-side hydrate","ref":"Phoenix.React.Helper.html#react_component/1"},{"type":"function","title":"Examples - Phoenix.React.Helper.react_component/1","doc":"<.react_component\n      component=\"awesome-chart\"\n      props={%{ data: @chart_data }}\n      static={false}\n    />\n\n### `component`\n\nComponent file is set at `Application.get_env(:phoenix_react_server, Phoenix.React)[:component_base]`\nThe component file should export a `Component` function:\n\n```javascript\nimport Chart from 'awesome-chart';\nexport const Component = ({data}) => {\n  return  ;\n}\n```","ref":"Phoenix.React.Helper.html#react_component/1-examples"},{"type":"function","title":"Attributes - Phoenix.React.Helper.react_component/1","doc":"* `component` (`:string`) (required) - react component name.\n* `props` (`:map`) - props will pass to react component. Defaults to `%{}`.\n* `static` (`:atom`) - when true, render to static markup\n  when false render to string\n  when nil render to readable stream\n\n  Defaults to `nil`. Must be one of `true`, `false`, or `nil`.","ref":"Phoenix.React.Helper.html#react_component/1-attributes"},{"type":"behaviour","title":"Phoenix.React.Runtime","doc":"Phoenix.React.Runtime\n\nManage the runtime of the React Render Server\n\nIf in dev mode, it will start a file watcher to watch the component directory.\nReload the server when the component file changed with a throttle time at `3s`.\n\n@behaviour Phoenix.React.Runtime","ref":"Phoenix.React.Runtime.html"},{"type":"function","title":"Phoenix.React.Runtime.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Phoenix.React.Runtime.html#child_spec/1"},{"type":"type","title":"Phoenix.React.Runtime.component/0","doc":"","ref":"Phoenix.React.Runtime.html#t:component/0"},{"type":"callback","title":"Phoenix.React.Runtime.config/0","doc":"","ref":"Phoenix.React.Runtime.html#c:config/0"},{"type":"type","title":"Phoenix.React.Runtime.html/0","doc":"","ref":"Phoenix.React.Runtime.html#t:html/0"},{"type":"function","title":"Phoenix.React.Runtime.init/1","doc":"Callback implementation for  DynamicSupervisor.init/1 .","ref":"Phoenix.React.Runtime.html#init/1"},{"type":"type","title":"Phoenix.React.Runtime.path/0","doc":"","ref":"Phoenix.React.Runtime.html#t:path/0"},{"type":"callback","title":"Phoenix.React.Runtime.render_to_readable_stream/4","doc":"","ref":"Phoenix.React.Runtime.html#c:render_to_readable_stream/4"},{"type":"callback","title":"Phoenix.React.Runtime.render_to_static_markup/4","doc":"","ref":"Phoenix.React.Runtime.html#c:render_to_static_markup/4"},{"type":"callback","title":"Phoenix.React.Runtime.render_to_string/4","doc":"","ref":"Phoenix.React.Runtime.html#c:render_to_string/4"},{"type":"callback","title":"Phoenix.React.Runtime.start/1","doc":"","ref":"Phoenix.React.Runtime.html#c:start/1"},{"type":"function","title":"Phoenix.React.Runtime.start_file_watcher/1","doc":"","ref":"Phoenix.React.Runtime.html#start_file_watcher/1"},{"type":"callback","title":"Phoenix.React.Runtime.start_file_watcher/1","doc":"","ref":"Phoenix.React.Runtime.html#c:start_file_watcher/1"},{"type":"function","title":"Phoenix.React.Runtime.start_link/1","doc":"","ref":"Phoenix.React.Runtime.html#start_link/1"},{"type":"function","title":"Phoenix.React.Runtime.start_runtime/2","doc":"","ref":"Phoenix.React.Runtime.html#start_runtime/2"},{"type":"type","title":"Phoenix.React.Runtime.t/0","doc":"","ref":"Phoenix.React.Runtime.html#t:t/0"},{"type":"module","title":"Phoenix.React.Runtime.Bun","doc":"Phoenix.React.Runtime.Bun\n\nConfig in `runtime.exs`\n\n```\nimport Config\n\nconfig :phoenix_react_server, Phoenix.React.Runtime.Bun,\n  cd: File.cwd!(),\n  cmd: \"/path/to/bun\",\n  # In dev mode, the server_js will be watched and recompiled when changed\n  # In prod mode, this need to be precompiled with `mix phx.react.bun.bundle`\n  server_js: Path.expand(\"bun/server.js\", :code.priv_dir(:phoenix_react_server)),\n  port: 5225,\n  env: :dev\n```","ref":"Phoenix.React.Runtime.Bun.html"},{"type":"type","title":"Phoenix.React.Runtime.Bun.body/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:body/0"},{"type":"function","title":"Phoenix.React.Runtime.Bun.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Phoenix.React.Runtime.Bun.html#child_spec/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.delete/3","doc":"Issues a DELETE request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#delete/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.delete!/3","doc":"Issues a DELETE request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#delete!/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.get/3","doc":"Issues a GET request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#get/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.get!/3","doc":"Issues a GET request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#get!/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.head/3","doc":"Issues a HEAD request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#head/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.head!/3","doc":"Issues a HEAD request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#head!/3"},{"type":"type","title":"Phoenix.React.Runtime.Bun.headers/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:headers/0"},{"type":"type","title":"Phoenix.React.Runtime.Bun.method/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:method/0"},{"type":"type","title":"Phoenix.React.Runtime.Bun.options/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:options/0"},{"type":"function","title":"Phoenix.React.Runtime.Bun.options/3","doc":"Issues an OPTIONS request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#options/3"},{"type":"function","title":"Phoenix.React.Runtime.Bun.options!/3","doc":"Issues a OPTIONS request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#options!/3"},{"type":"type","title":"Phoenix.React.Runtime.Bun.params/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:params/0"},{"type":"function","title":"Phoenix.React.Runtime.Bun.patch/4","doc":"Issues a PATCH request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#patch/4"},{"type":"function","title":"Phoenix.React.Runtime.Bun.patch!/4","doc":"Issues a PATCH request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#patch!/4"},{"type":"function","title":"Phoenix.React.Runtime.Bun.post/4","doc":"Issues a POST request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#post/4"},{"type":"function","title":"Phoenix.React.Runtime.Bun.post!/4","doc":"Issues a POST request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#post!/4"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_headers/1","doc":"Callback implementation for  HTTPoison.Base.process_headers/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_headers/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_request_body/1","doc":"Callback implementation for  HTTPoison.Base.process_request_body/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_request_body/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_request_headers/1","doc":"Callback implementation for  HTTPoison.Base.process_request_headers/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_request_headers/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_request_params/1","doc":"Callback implementation for  HTTPoison.Base.process_request_params/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_request_params/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_request_url/1","doc":"Callback implementation for  HTTPoison.Base.process_request_url/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_request_url/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_response/1","doc":"Callback implementation for  HTTPoison.Base.process_response/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_response/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_response_body/1","doc":"Callback implementation for  HTTPoison.Base.process_response_body/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_response_body/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_response_chunk/1","doc":"Callback implementation for  HTTPoison.Base.process_response_chunk/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_response_chunk/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_response_headers/1","doc":"Callback implementation for  HTTPoison.Base.process_response_headers/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_response_headers/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_response_status_code/1","doc":"Callback implementation for  HTTPoison.Base.process_response_status_code/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_response_status_code/1"},{"type":"macro","title":"Phoenix.React.Runtime.Bun.process_result/1","doc":"","ref":"Phoenix.React.Runtime.Bun.html#process_result/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_status_code/1","doc":"Callback implementation for  HTTPoison.Base.process_status_code/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_status_code/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.process_url/1","doc":"Callback implementation for  HTTPoison.Base.process_url/1 .","ref":"Phoenix.React.Runtime.Bun.html#process_url/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.put/4","doc":"Issues a PUT request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#put/4"},{"type":"function","title":"Phoenix.React.Runtime.Bun.put!/4","doc":"Issues a PUT request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#put!/4"},{"type":"type","title":"Phoenix.React.Runtime.Bun.request/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:request/0"},{"type":"function","title":"Phoenix.React.Runtime.Bun.request/1","doc":"Issues an HTTP request using an `HTTPoison.Request` struct.\n\nThis function returns `{:ok, response}`, `{:ok, async_response}`, or `{:ok, maybe_redirect}`\nif the request is successful, `{:error, reason}` otherwise.","ref":"Phoenix.React.Runtime.Bun.html#request/1"},{"type":"function","title":"Redirect handling - Phoenix.React.Runtime.Bun.request/1","doc":"If the option `:follow_redirect` is given, HTTP redirects are automatically follow if\nthe method is set to `:get` or `:head` and the response's `status_code` is `301`, `302` or\n`307`.\n\nIf the method is set to `:post`, then the only `status_code` that get's automatically\nfollowed is `303`.\n\nIf any other method or `status_code` is returned, then this function returns a\nreturns a `{:ok, %HTTPoison.MaybeRedirect{}}` containing the `redirect_url` for you to\nre-request with the method set to `:get`.","ref":"Phoenix.React.Runtime.Bun.html#request/1-redirect-handling"},{"type":"function","title":"Examples - Phoenix.React.Runtime.Bun.request/1","doc":"request = %HTTPoison.Request{\n      method: :post,\n      url: \"https://my.website.com\",\n      body: \"{\\\"foo\\\": 3}\",\n      headers: [{\"Accept\", \"application/json\"}]\n    }\n\n    request(request)","ref":"Phoenix.React.Runtime.Bun.html#request/1-examples"},{"type":"function","title":"Phoenix.React.Runtime.Bun.request/5","doc":"Issues an HTTP request with the given method to the given url.\n\nThis function is usually used indirectly by `get/3`, `post/4`, `put/4`, etc\n\nArgs:\n  * `method` - HTTP method as an atom (`:get`, `:head`, `:post`, `:put`,\n    `:delete`, etc.)\n  * `url` - target url as a binary string or char list\n  * `body` - request body. See more below\n  * `headers` - HTTP headers as an orddict (e.g., `[{\"Accept\", \"application/json\"}]`)\n  * `options` - Keyword list of options\n\nBody: see type `HTTPoison.Request`\n\nOptions: see type `HTTPoison.Request`\n\nThis function returns `{:ok, response}`, `{:ok, async_response}`, or `{:ok, maybe_redirect}`\nif the request is successful, `{:error, reason}` otherwise.","ref":"Phoenix.React.Runtime.Bun.html#request/5"},{"type":"function","title":"Redirect handling - Phoenix.React.Runtime.Bun.request/5","doc":"If the option `:follow_redirect` is given, HTTP redirects are automatically follow if\nthe method is set to `:get` or `:head` and the response's `status_code` is `301`, `302` or\n`307`.\n\nIf the method is set to `:post`, then the only `status_code` that get's automatically\nfollowed is `303`.\n\nIf any other method or `status_code` is returned, then this function returns a\nreturns a `{:ok, %HTTPoison.MaybeRedirect{}}` containing the `redirect_url` for you to\nre-request with the method set to `:get`.","ref":"Phoenix.React.Runtime.Bun.html#request/5-redirect-handling"},{"type":"function","title":"Examples - Phoenix.React.Runtime.Bun.request/5","doc":"request(:post, \"https://my.website.com\", \"{\\\"foo\\\": 3}\", [{\"Accept\", \"application/json\"}])","ref":"Phoenix.React.Runtime.Bun.html#request/5-examples"},{"type":"function","title":"Phoenix.React.Runtime.Bun.request!/1","doc":"Issues an HTTP request an `HTTPoison.Request` struct.\nexception in case of failure.\n\n`request!/1` works exactly like `request/1` but it returns just the\nresponse in case of a successful request, raising an exception in case the\nrequest fails.","ref":"Phoenix.React.Runtime.Bun.html#request!/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.request!/5","doc":"Issues an HTTP request with the given method to the given url, raising an\nexception in case of failure.\n\n`request!/5` works exactly like `request/5` but it returns just the\nresponse in case of a successful request, raising an exception in case the\nrequest fails.","ref":"Phoenix.React.Runtime.Bun.html#request!/5"},{"type":"function","title":"Phoenix.React.Runtime.Bun.start/0","doc":"Starts HTTPoison and its dependencies.","ref":"Phoenix.React.Runtime.Bun.html#start/0"},{"type":"function","title":"Phoenix.React.Runtime.Bun.start_link/1","doc":"","ref":"Phoenix.React.Runtime.Bun.html#start_link/1"},{"type":"function","title":"Phoenix.React.Runtime.Bun.stream_next/1","doc":"Requests the next message to be streamed for a given `HTTPoison.AsyncResponse`.\n\nSee `request!/5` for more detailed information.","ref":"Phoenix.React.Runtime.Bun.html#stream_next/1"},{"type":"type","title":"Phoenix.React.Runtime.Bun.url/0","doc":"","ref":"Phoenix.React.Runtime.Bun.html#t:url/0"},{"type":"module","title":"Phoenix.React.Server","doc":"The React Render Server\n\nStart React Render server by setting.\n\n```\nconfig :phoenix_react_server, Phoenix.React,\n  runtime: Phoenix.React.Runtime.Bun,\n  component_base: Path.expand(\"../assets/component\", __DIR__),\n  cache_ttl: 10\n```","ref":"Phoenix.React.Server.html"},{"type":"function","title":"Phoenix.React.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Phoenix.React.Server.html#child_spec/1"},{"type":"function","title":"Phoenix.React.Server.config/0","doc":"Return the configuration of the React Render Server from `Application.get_env(:phoenix_react_server, Phoenix.React)`","ref":"Phoenix.React.Server.html#config/0"},{"type":"type","title":"Phoenix.React.Server.millisecond/0","doc":"","ref":"Phoenix.React.Server.html#t:millisecond/0"},{"type":"type","title":"Phoenix.React.Server.second/0","doc":"","ref":"Phoenix.React.Server.html#t:second/0"},{"type":"function","title":"Phoenix.React.Server.set_runtime_process/1","doc":"","ref":"Phoenix.React.Server.html#set_runtime_process/1"},{"type":"function","title":"Phoenix.React.Server.start_link/1","doc":"","ref":"Phoenix.React.Server.html#start_link/1"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Phoenix.React","doc":"# Phoenix.React\n\n[![CI](https://github.com/gsmlg-dev/phoenix-react/actions/workflows/ci.yml/badge.svg)](https://github.com/gsmlg-dev/phoenix-react/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/phoenix_react_server.svg)](https://hex.pm/packages/phoenix_react_server)\n[![Hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/phoenix_react_server/)\n[![Hex.pm](https://img.shields.io/hexpm/dt/phoenix_react_server.svg)](https://hex.pm/packages/phoenix_react_server)\n[![Hex.pm](https://img.shields.io/hexpm/dw/phoenix_react_server.svg)](https://hex.pm/packages/phoenix_react_server)\n\nRun a `react` render server to render react component in `Phoenix` html.\n\n**Features**\n\n- [x] Render to static markup\n- [x] Render to string\n- [x] Render to readable stream\n- [x] Hydrate at client side\n- [x] Connect to Live View render\n\nSee the [docs](https://hexdocs.pm/phoenix_react_server/) for more information.","ref":"readme.html"},{"type":"extras","title":"Install this package - Phoenix.React","doc":"Add deps in `mix.exs`\n\n```elixir\n{:phoenix_react_server, \"~> 0.6.1\"},\n```","ref":"readme.html#install-this-package"},{"type":"extras","title":"Configuration - Phoenix.React","doc":"Set config, runtime, react components, etc.\n\n```elixir\nimport Config\n\nconfig :phoenix_react_server, Phoenix.React,\n  # react runtime, default to `bun`\n  runtime: Phoenix.React.Runtime.Bun,\n  # react component base path\n  component_base: Path.expand(\"../assets/component\", __DIR__),\n  # cache ttl, default to 60 seconds\n  cache_ttl: 60\n```\n\nSupported `runtime`\n\n- [x] `Phoenix.React.Runtime.Bun`\n- [ ] `Phoenix.React.Runtime.Deno`\n\nAdd Render Server in your application Supervisor tree.\n\n```elixir\n  def start(_type, _args) do\n    children = [\n      ReactDemoWeb.Telemetry,\n      {DNSCluster, query: Application.get_env(:react_demo, :dns_cluster_query) || :ignore},\n      {Phoenix.PubSub, name: ReactDemo.PubSub},\n      # React render service\n      Phoenix.React,\n      ReactDemoWeb.Endpoint\n    ]\n\n    opts = [strategy: :one_for_one, name: ReactDemo.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n```\n\nWrite Phoenix Component use `react_component`\n\n```elixir\ndefmodule ReactDemoWeb.ReactComponents do\n  use Phoenix.Component\n\n  import Phoenix.React.Helper\n\n  def react_markdown(assigns) do\n    {static, props} = Map.pop(assigns, :static, true)\n\n    react_component(%{\n      component: \"markdown\",\n      props: props,\n      static: static\n    })\n  end\nend\n```\n\nImport in html helpers in `react_demo_web.ex`\n\n```elixir\n  defp html_helpers do\n    quote do\n      # Translation\n      use Gettext, backend: ReactDemoWeb.Gettext\n\n      # HTML escaping functionality\n      import Phoenix.HTML\n      # Core UI components\n      import ReactDemoWeb.CoreComponents\n      import ReactDemoWeb.ReactComponents\n\n      ...\n    end\n  end\n```\n\n### `render_to_static_markup`\n\nThen you can use react server rendered component in Phoenix Component\n\n```html\n \n   \n     Hello There \n    <.react_markdown\n      data={@data}\n    >\n   \n \n```\n\n### `render_to_string`\n\n```html\n \n   \n     \n      This  Table  is rendered with  react-dom/server \n     \n    <!-- Notice: Remove white space in the react render node or it will break hydrate -->\n    <!-- Add `phx-no-format` to avoid mix format change the code here -->\n     <.react_system_stats\n      data={@data}\n    /> \n   \n \n```\n\n* Then hydrate on the client.\n\n```js\n\ndocument.addEventListener('DOMContentLoaded', function() {\n  const store = new Store();\n  const domContainer = document.querySelector('#system_usage_container');\n  if (domContainer) {\n    let channel = socket.channel(\"system_usage:lobby\", {});\n\n    channel.join()\n      .receive(\"ok\", resp => { console.log(\"Joined successfully\", resp) })\n      .receive(\"error\", resp => { console.log(\"Unable to join\", resp) });\n\n\n    function Usage(props) {\n      const data = useSyncExternalStore(store.subscribe, store.getSnapshot, store.getServerSnapshot);\n\n      return  ;\n    }\n\n    let root;\n\n    channel.on(\"joined\", (data) => {\n      // console.log(\"Reset stats: \", data)\n      store.reset(data.data)\n\n      requestAnimationFrame(() => {\n        hydrateRoot(domContainer,  );\n      });\n    });\n\n    channel.on(\"stats\", (data) => {\n      // console.log(\"Stats: \", data)\n      store.unshift(data)\n    });\n\n  }\n});\n\n```\n\n### `render_to_readable_stream`\n\n```html\n <.react_live_form\n  data={@form_data}\n/> \n```\n\n* Work with `LiveView`\n\n```js\n\nconst hooks = {\n  LiveFormHook: {\n    mounted() {\n      const formState = new FormState();\n\n      formState.setData = (data) => {\n        this.pushEvent(\"form:input\", data);\n      };\n\n      function LiveViewForm(props) {\n        const data = useSyncExternalStore(formState.subscribe, formState.getSnapshot, formState.getServerSnapshot);\n        return  ;\n      }\n\n      this.pushEvent(\"form:init\", {}, (data, ref) => {\n        formState.reset(data);\n        this.reactRoot = hydrateRoot(this.el,  );\n      });\n      this.handleEvent(\"form:update\", (data) => {\n        formState.assign(data);\n      });\n    },\n  }\n}\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Run in release mode - Phoenix.React","doc":"Bundle components with server.js to one file.\n\n```shell\nmix phx.react.bun.bundle --component-base=assets/component --output=priv/react/server.js \n```\n\nConfig `runtime` to `Phoenix.React.Runtime.Bun` in `runtime.exs`\n\n```elixir\n\nconfig :phoenix_react_server, Phoenix.React.Runtime.Bun,\n  cmd: System.find_executable(\"bun\"),\n  server_js: Path.expand(\"../priv/react/server.js\", __DIR__),\n  port: 12666,\n  env: :prod\n```","ref":"readme.html#run-in-release-mode"},{"type":"extras","title":"Hydrate at client side with CDN - Phoenix.React","doc":"Hydrate react component at client side when CDN.\n\n```html\n \n  {\n    \"imports\": {\n      \"react-dom\": \"https://esm.run/react-dom@19\",\n      \"app\": \"https://my.web.site/app.js\"\n    }\n  }\n \n \nimport { hydrateRoot } from 'react-dom/client';\nimport { Component } from 'app';\n\nhydrateRoot(\n  document.getElementById('app-wrapper'),\n   \n);\n \n```\n\n# DEMO\n\nPath `./react_demo`","ref":"readme.html#hydrate-at-client-side-with-cdn"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.38.2"}}